-------------------------------------------------------------------------------
-- All the gameplay constants for the buff spells that can be cast
-------------------------------------------------------------------------------
FFY_TYPE_NORMAL         = 1;
FFY_TYPE_BLESSING       = 2;
FFY_TYPE_PARTYBLESSING  = 3;
FFY_TYPE_WEAPON         = 4;
FFY_TYPE_SELF           = 5;
FFY_TYPE_GROUP          = 6;
FFY_TYPE_RISKY          = 7;
FFY_TYPE_CASTERSONLY    = 8;

FFY_SPELL_DATA = {
    [FFY_CLASS_PRIEST] = {
        [FFY_SPELL_PRYR_FORTITUDE] = {
            shortcut =  { "prayer", "group fort", "group fortitude", "group stam", "group stamina" },
            behavior = FFY_TYPE_GROUP,
            levels = { 48, 60 },
            manacost = { 2600, 3400 },
            duration = { 3600.0 },
        },
        [FFY_SPELL_FORTITUDE] = {
            shortcut =  { "fort", "fortitude", "stam", "stamina" },
            behavior = FFY_TYPE_NORMAL,
            levels = { 1, 12, 24, 36, 48, 60 },
            manacost = { 60, 155, 400, 745, 1170, 1695 },
            duration = { 1800.0 },
        },
        [FFY_SPELL_SHADOWPROT] = {
            shortcut =  { "shadow" },
            behavior = FFY_TYPE_NORMAL,
            levels = { 30, 42, 56 },
            manacost = { 250, 450, 650 },
            duration = { 600.0 },
        },
        [FFY_SPELL_DIVINESPIRIT] = {
            shortcut =  { "spirit" },
            behavior = FFY_TYPE_CASTERSONLY,
            levels = { 40, 47, 54 },
            manacost = { 420, 610, 860 },
            duration = { 1800.0 },
        },
        [FFY_SPELL_INNERFIRE] = {
            shortcut =  { "inner" },
            behavior = FFY_TYPE_SELF,
            levels = { 12, 20, 30, 40, 50, 60 },
            manacost = { 20, 45, 75, 115, 165, 225 },
            duration = { 180.0 },
        },
        [FFY_SPELL_ELUNESGRACE] = {
            shortcut =  { "elune" },
            behavior = FFY_TYPE_SELF,
            levels = { 20,30,40,50,60 } ,
            manacost = { 150, 230, 350, 465, 575 },
            duration = { 180.0 },
        },
        [FFY_SPELL_SHADOWGUARD] = {
            shortcut =  { "guard" },
            behavior = FFY_TYPE_SELF,
            levels = { 20, 28, 36, 44, 52, 60 } ,
            manacost = { 50, 85, 120, 160, 200, 250 },
            duration = { 600.0 },
        },
        [FFY_SPELL_FEEDBACK] = {
            shortcut =  { "feed", "feedback" },
            behavior = FFY_TYPE_WEAPON,
            levels = { 20, 30, 40, 50, 60 } ,
            manacost = { 140, 245, 355, 470, 580 },
            duration = { 300.0 },
        },
    },
    [FFY_CLASS_DRUID] = {
        [FFY_SPELL_GIFTWILD] = {
            shortcut =  { "gift" },
            behavior = FFY_TYPE_GROUP,
            levels = { 50, 60 },
            manacost = { 900, 1200 },
            duration = { 3600.0 },
        },
        [FFY_SPELL_MARKWILD] = {
            shortcut =  { "mark" },
            behavior = FFY_TYPE_NORMAL,
            levels = { 1, 10, 20, 30, 40, 50, 60 },
            manacost = { 20, 50, 100, 160, 240, 340, 445 },
            duration = { 1800.0 },
        },
        [FFY_SPELL_THORNS] = {
            shortcut =  { "thorns" },
            behavior = FFY_TYPE_NORMAL,
            levels = { 6, 14, 24, 34, 44, 54 },
            manacost = { 35, 60, 105, 170, 240, 320 },
            duration = { 600.0 },
        },
    },
    [FFY_CLASS_PALADIN] = {
        [FFY_BLESSING_KINGS] = {
            shortcut =  { "kings" },
            behavior = FFY_TYPE_BLESSING,
            levels = { 40 },
            manacost = { 75 },
            duration = { 300.0 },
        },
        [FFY_BLESSING_SANCTUARY] = {
            shortcut =  { "sanctuary", "sanct" },
            behavior = FFY_TYPE_BLESSING,
            levels = { 20, 30, 40, 50, 60 },
            manacost = { 60, 85, 110, 135 },
            duration = { 300.0 },
        },
        [FFY_BLESSING_MIGHT] = {
            shortcut =  { "might" },
            behavior = FFY_TYPE_BLESSING,
            levels = { 4, 12, 22, 32, 42, 52 },
            manacost = { 20, 30, 45, 60, 85, 110 },
            duration = { 300.0 },
        },
        [FFY_BLESSING_WISDOM] = {
            shortcut =  { "wisdom" },
            behavior = FFY_TYPE_BLESSING,
            levels = { 14, 24, 34, 44, 54 },
            manacost = { 30, 45, 65, 90, 115 },
            duration = { 300.0 },
        },
        [FFY_BLESSING_SALVATION] = {
            shortcut =  { "salvation", "salv" },
            behavior = FFY_TYPE_PARTYBLESSING,
            levels = { 26 },
            manacost = { 0 },
            duration = { 300.0 },
        },
        [FFY_BLESSING_LIGHT] = {
            shortcut =  { "light" },
            behavior = FFY_TYPE_BLESSING,
            levels = { 40, 50, 60 },
            manacost = { 85, 110, 135 },
            duration = { 300.0 },
        },
    },
    [FFY_CLASS_MAGE] = {
        [FFY_SPELL_ARCANEBRILLIANCE] = {
            shortcut =  { "brilliance" },
            behavior = FFY_TYPE_GROUP,
            levels = { 56 },
            manacost = { 3400 },
            duration = { 3600.0 },
        },
        [FFY_SPELL_ARCANEINT] = {
            shortcut =  { "arcane" },
            behavior = FFY_TYPE_NORMAL,
            levels = { 1, 14, 28, 42, 56 },
            manacost = { 60, 185, 520, 945, 1510 },
            duration = { 1800.0 },
        },
        [FFY_SPELL_AMPLIFYMAGIC] = {
            shortcut =  { "amplify" },
            behavior = FFY_TYPE_RISKY,
            levels = { 18, 30, 42, 54 },
            manacost = { 150, 250, 350, 450 },
            duration = { 600.0 },
        },
        [FFY_SPELL_DAMPENMAGIC] = {
            shortcut =  { "dampen" },
            behavior = FFY_TYPE_RISKY,
            levels = { 12, 24, 36, 48, 60 },
            manacost = { 100, 200, 300, 400, 500 },
            duration = { 600.0 },
        },
        [FFY_SPELL_FROSTARMOR] = {
            shortcut =  { "frost" },
            behavior = FFY_TYPE_SELF,
            levels = { 1, 10, 20 },
            manacost = { 60, 110, 170 },
            duration = { 1800.0 },
        },
        [FFY_SPELL_ICEARMOR] = {
            shortcut =  { "ice" },
            behavior = FFY_TYPE_SELF,
            levels = { 30, 40, 50, 60 },
            manacost = { 240, 320, 410, 500 },
            duration = { 1800.0 },
        },
        [FFY_SPELL_MAGEARMOR] = {
            shortcut =  { "mage" },
            behavior = FFY_TYPE_SELF,
            levels = { 34, 46, 58 },
            manacost = { 270, 380, 490 },
            duration = { 1800.0 },
        },
    },
    [FFY_CLASS_WARLOCK] = {
        [FFY_SPELL_DEMONSKIN] = {
            shortcut =  { "demon" },
            behavior = FFY_TYPE_SELF,
            levels = { 1, 10 },
            manacost = { 50, 120 },
            duration = { 1800.0 },
        },
    },
}
